# Birdcall

![Status: Stable & Ongoing](https://img.shields.io/badge/status-Stable%20&%20Ongoing-green.svg)

A Python module, and a collection of Python scripts, for serverless Twitter bots and CLI-based operations. Leverages                  
[Tweepy](https://www.tweepy.org/) and other techniques.

Birdcall is used by bots like [@indiedevtracker](https://twitter.com/indiedevtracker), which automatically provides a
curated stream of content from the indie game development community.

## Setup

This project uses Python Virtual Environments for development and deployment. This makes it possible to install packages
using `pip` specifically for this project without affecting the rest of the host system. Dependencies are listed in the
repository's `requirements.txt` file.
